ScreenSize class

Represents the size of a screen.

Available extensions

Constructors

ScreenSize(double width, double height)
const

Properties

aspectRatio → double
no setter
calculator → ScreenCalculator

Available on ScreenSize, provided by the CalculatorOnScreenSizeExtension extension

The calculator for the screen size.
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited