Plug in a custom layout resolver. Returning null falls back to the
default AppLayout.fromSize classification. Useful for embedding the
screen in a constrained sub-window or for non-standard form factors.
Activates for mobile device screen sizes with a horizontal orientation.
Override to customize the layout for these sizes. The body includes the
widget returned by horizontalMobileBody.
Activates for screen sizes that do not match the criteria for
mobileLayout, horizontalMobileLayout, narrowLayout, or wideLayout.
Override to customize these sizes. The body includes the widget returned
by body.
Activates for non-mobile narrow screen sizes, such as a narrow desktop
window or screen. Override to customize the layout for these sizes. The
body includes the widget returned by narrowBody.
Triggers a rebuild of this screen. Provided for controllers (which
don't have direct access to State.setState) and other external
callers. No-ops when the state is no longer mounted.
Removes the controller associated with this screen from the cache and
disposes it. Use this when you explicitly want to discard a cached
controller (e.g. on logout) without waiting for controllerTimeout.
Override to specify the side insets for the body. Side insets are
applied to the top, bottom, left, and right of the body. They are
added to the padding.
Activates for non-mobile wide screen sizes, such as a wide desktop
window or screen. Override to customize the layout for these sizes. The
body includes the widget returned by wideBody.